@@ -22,23 +22,24 @@ from kolla.version import version_info as version
 BASE_OS_DISTRO = ['centos', 'rhel', 'ubuntu', 'debian']
 BASE_ARCH = ['x86_64', 'ppc64le', 'aarch64']
 DEFAULT_BASE_TAGS = {
-     'centos': {'name': 'quay.io/centos/centos', 'tag': 'stream8'},
-     'rhel': {'name': 'registry.access.redhat.com/ubi8', 'tag': 'latest'},
-     'debian': {'name': 'debian', 'tag': '10'},
-     'ubuntu': {'name': 'ubuntu', 'tag': '20.04'},
+    'centos': {'name': 'quay.io/centos/centos', 'tag': 'stream8'},
+    'rhel': {'name': 'registry.access.redhat.com/ubi8', 'tag': 'latest'},
+    'debian': {'name': 'debian', 'tag': 'bullseye'},
+    'ubuntu': {'name': 'ubuntu', 'tag': '20.04'},
 }
-DISTRO_RELEASE = {
-    'centos': '8',
-    'rhel': '8',
-    'debian': '10',
-    'ubuntu': '20.04',
+# NOTE(hrw): has to match PRETTY_NAME in /etc/os-release
+DISTRO_PRETTY_NAME = {
+    'centos': 'CentOS Stream 8',
+    'rhel': 'Red Hat Enterprise Linux 8',
+    'debian': 'Debian GNU/Linux 11 (bullseye)',
+    'ubuntu': 'Ubuntu 20.04',
 }
-OPENSTACK_RELEASE = 'victoria'
+OPENSTACK_RELEASE = 'wallaby'
 
 # This is noarch repository so we will use it on all architectures
-DELOREAN = "https://trunk.rdoproject.org/centos8-master/" \
+DELOREAN = "https://trunk.rdoproject.org/centos8-wallaby/" \
     "consistent/delorean.repo"
-DELOREAN_DEPS = "https://trunk.rdoproject.org/centos8-master/" \
+DELOREAN_DEPS = "https://trunk.rdoproject.org/centos8-wallaby/" \
     "delorean-deps.repo"
 
 INSTALL_TYPE_CHOICES = ['binary', 'source', 'rdo', 'rhos']
@@ -50,7 +51,6 @@ TARBALLS_BASE = "https://tarballs.opendev.org"
 _PROFILE_OPTS = [
     cfg.ListOpt('infra',
                 default=[
-                    'certmonger',
                     'cron',
                     'elasticsearch',
                     'etcd',
@@ -64,11 +64,9 @@ _PROFILE_OPTS = [
                     'mariadb',
                     'memcached',
                     'openvswitch',
-                    'ptp',
                     'qdrouterd',
                     'rabbitmq',
                     'redis',
-                    'rsyslog',
                     'skydive',
                     'storm',
                     'tgtd',
@@ -95,13 +93,11 @@ _PROFILE_OPTS = [
                     'blazar',
                     'cloudkitty',
                     'designate',
-                    'ec2-api',
                     'freezer',
                     'gnocchi',
                     'influxdb',
                     'ironic',
                     'kafka',
-                    'karbor',
                     'kuryr',
                     'magnum',
                     'manila',
@@ -109,21 +105,17 @@ _PROFILE_OPTS = [
                     'mistral',
                     'monasca',
                     'murano',
-                    'novajoin',
                     'octavia',
                     'panko',
-                    'qinling',
                     'rally',
                     'redis',
                     'sahara',
-                    'searchlight',
                     'senlin',
                     'solum',
                     'tacker',
                     'telegraf',
                     'trove',
                     'vitrage',
-                    'zaqar',
                     'zookeeper',
                     'zun',
                 ],
@@ -182,7 +174,7 @@ _CLI_OPTS = [
                 help='Show all available images (filtering supported)'),
     cfg.StrOpt('namespace', short='n', default='kolla',
                help='The Docker namespace name'),
-    cfg.StrOpt('network_mode', default=None,
+    cfg.StrOpt('network_mode', default='host',
                help='The network mode for Docker build. Example: host'),
     cfg.BoolOpt('cache', default=True,
                 help='Use the Docker cache when building'),
@@ -281,7 +273,9 @@ _BASE_OPTS = [
     cfg.StrOpt('squash-tmp-dir',
                help='Temporary directory to be used during squashing'),
     cfg.BoolOpt('clean_package_cache', default=True,
-                help='Clean all package cache.')
+                help='Clean all package cache.'),
+    cfg.ListOpt('allowed-to-fail', default=[],
+                help='Images which are allowed to fail'),
 ]
 
 
@@ -289,349 +283,297 @@ SOURCES = {
     'openstack-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/requirements/'
-                     'requirements-stable-victoria.tar.gz')},
+                     'requirements-${openstack_branch}.tar.gz')},
     'aodh-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/aodh/'
-                     'aodh-stable-victoria.tar.gz')},
+                     'aodh-${openstack_branch}.tar.gz')},
     'barbican-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/barbican/'
-                     'barbican-stable-victoria.tar.gz')},
+                     'barbican-${openstack_branch}.tar.gz')},
     'bifrost-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/bifrost/'
-                     'bifrost-stable-victoria.tar.gz')},
+                     'bifrost-${openstack_branch}.tar.gz')},
     'blazar-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar/'
-                     'blazar-stable-victoria.tar.gz')},
+                     'blazar-${openstack_branch}.tar.gz')},
     'ceilometer-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ceilometer/'
-                     'ceilometer-stable-victoria.tar.gz')},
+                     'ceilometer-${openstack_branch}.tar.gz')},
     'ceilometer-base-plugin-panko': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/panko/'
-                     'panko-stable-victoria.tar.gz')},
+                     'panko-${openstack_branch}.tar.gz')},
     'cinder-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cinder/'
-                     'cinder-stable-victoria.tar.gz')},
+                     'cinder-${openstack_branch}.tar.gz')},
     'cloudkitty-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cloudkitty/'
-                     'cloudkitty-stable-victoria.tar.gz')},
+                     'cloudkitty-${openstack_branch}.tar.gz')},
     'cyborg-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cyborg/'
-                     'cyborg-stable-victoria.tar.gz')},
+                     'cyborg-${openstack_branch}.tar.gz')},
     'designate-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/designate/'
-                     'designate-stable-victoria.tar.gz')},
-    'ec2-api': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/ec2-api/'
-                     'ec2-api-stable-victoria.tar.gz')},
+                     'designate-${openstack_branch}.tar.gz')},
     'freezer-api': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/freezer-api/'
-                     'freezer-api-stable-victoria.tar.gz')},
+                     'freezer-api-${openstack_branch}.tar.gz')},
     'freezer-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/freezer/'
-                     'freezer-stable-victoria.tar.gz')},
+                     'freezer-${openstack_branch}.tar.gz')},
     'glance-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/glance/'
-                     'glance-stable-victoria.tar.gz')},
+                     'glance-${openstack_branch}.tar.gz')},
     'gnocchi-base': {
         'type': 'git',
-        'reference': '4.3.4',
+        'reference': '4.4.0',
         'location': ('https://github.com/gnocchixyz/'
                      'gnocchi.git')},
     'heat-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/heat/'
-                     'heat-stable-victoria.tar.gz')},
+                     'heat-${openstack_branch}.tar.gz')},
     'horizon': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/horizon/'
-                     'horizon-stable-victoria.tar.gz')},
+                     'horizon-${openstack_branch}.tar.gz')},
     'horizon-plugin-blazar-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar-dashboard/'
-                     'blazar-dashboard-stable-victoria.tar.gz')},
+                     'blazar-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-cloudkitty-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cloudkitty-dashboard/'
-                     'cloudkitty-dashboard-stable-victoria.tar.gz')},
+                     'cloudkitty-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-designate-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/designate-dashboard/'
-                     'designate-dashboard-stable-victoria.tar.gz')},
+                     'designate-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-freezer-web-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/freezer-web-ui/'
-                     'freezer-web-ui-stable-victoria.tar.gz')},
+                     'freezer-web-ui-${openstack_branch}.tar.gz')},
     'horizon-plugin-heat-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/heat-dashboard/'
-                     'heat-dashboard-stable-victoria.tar.gz')},
+                     'heat-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-ironic-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic-ui/'
-                     'ironic-ui-stable-victoria.tar.gz')},
-    'horizon-plugin-karbor-dashboard': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/karbor-dashboard/'
-                     'karbor-dashboard-stable-victoria.tar.gz')},
+                     'ironic-ui-${openstack_branch}.tar.gz')},
     'horizon-plugin-magnum-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/magnum-ui/'
-                     'magnum-ui-stable-victoria.tar.gz')},
+                     'magnum-ui-${openstack_branch}.tar.gz')},
     'horizon-plugin-manila-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/manila-ui/'
-                     'manila-ui-stable-victoria.tar.gz')},
+                     'manila-ui-${openstack_branch}.tar.gz')},
     'horizon-plugin-masakari-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/masakari-dashboard/'
-                     'masakari-dashboard-stable-victoria.tar.gz')},
+                     'masakari-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-mistral-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/mistral-dashboard/'
-                     'mistral-dashboard-stable-victoria.tar.gz')},
+                     'mistral-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-monasca-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-ui/'
-                     'monasca-ui-stable-victoria.tar.gz')},
+                     'monasca-ui-${openstack_branch}.tar.gz')},
     'horizon-plugin-murano-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/murano-dashboard/'
-                     'murano-dashboard-stable-victoria.tar.gz')},
+                     'murano-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-neutron-vpnaas-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-vpnaas-dashboard/'
-                     'neutron-vpnaas-dashboard-stable-victoria.tar.gz')},
+                     'neutron-vpnaas-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-octavia-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/octavia-dashboard/'
-                     'octavia-dashboard-stable-victoria.tar.gz')},
-    'horizon-plugin-qinling-dashboard': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/qinling-dashboard/'
-                     'qinling-dashboard-stable-victoria.tar.gz')},
+                     'octavia-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-sahara-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-dashboard/'
-                     'sahara-dashboard-stable-victoria.tar.gz')},
-    'horizon-plugin-searchlight-ui': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/searchlight-ui/'
-                     'searchlight-ui-stable-victoria.tar.gz')},
+                     'sahara-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-senlin-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/senlin-dashboard/'
-                     'senlin-dashboard-stable-victoria.tar.gz')},
+                     'senlin-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-solum-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/solum-dashboard/'
-                     'solum-dashboard-stable-victoria.tar.gz')},
+                     'solum-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-tacker-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tacker-horizon/'
-                     'tacker-horizon-stable-victoria.tar.gz')},
+                     'tacker-horizon-${openstack_branch}.tar.gz')},
     'horizon-plugin-trove-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/trove-dashboard/'
-                     'trove-dashboard-stable-victoria.tar.gz')},
+                     'trove-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-vitrage-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vitrage-dashboard/'
-                     'vitrage-dashboard-stable-victoria.tar.gz')},
+                     'vitrage-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-watcher-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/watcher-dashboard/'
-                     'watcher-dashboard-stable-victoria.tar.gz')},
-    'horizon-plugin-zaqar-ui': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/zaqar-ui/'
-                     'zaqar-ui-stable-victoria.tar.gz')},
+                     'watcher-dashboard-${openstack_branch}.tar.gz')},
     'horizon-plugin-zun-ui': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zun-ui/'
-                     'zun-ui-stable-victoria.tar.gz')},
+                     'zun-ui-${openstack_branch}.tar.gz')},
     'ironic-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic/'
-                     'ironic-stable-victoria.tar.gz')},
+                     'ironic-${openstack_branch}.tar.gz')},
     'ironic-inspector': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic-inspector/'
-                     'ironic-inspector-stable-victoria.tar.gz')},
-    'karbor-base': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/karbor/'
-                     'karbor-stable-victoria.tar.gz')},
+                     'ironic-inspector-${openstack_branch}.tar.gz')},
     'keystone-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/keystone/'
-                     'keystone-stable-victoria.tar.gz')},
+                     'keystone-${openstack_branch}.tar.gz')},
     'kuryr-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/kuryr/'
-                     'kuryr-stable-victoria.tar.gz')},
+                     'kuryr-${openstack_branch}.tar.gz')},
     'kuryr-libnetwork': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/kuryr-libnetwork/'
-                     'kuryr-libnetwork-stable-victoria.tar.gz')},
+                     'kuryr-libnetwork-${openstack_branch}.tar.gz')},
     'magnum-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/magnum/'
-                     'magnum-stable-victoria.tar.gz')},
+                     'magnum-${openstack_branch}.tar.gz')},
     'manila-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/manila/'
-                     'manila-stable-victoria.tar.gz')},
+                     'manila-${openstack_branch}.tar.gz')},
     'masakari-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/masakari/'
-                     'masakari-stable-victoria.tar.gz')},
+                     'masakari-${openstack_branch}.tar.gz')},
     'masakari-monitors': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/masakari-monitors/'
-                     'masakari-monitors-stable-victoria.tar.gz')},
+                     'masakari-monitors-${openstack_branch}.tar.gz')},
     'mistral-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/mistral/'
-                     'mistral-stable-victoria.tar.gz')},
+                     'mistral-${openstack_branch}.tar.gz')},
     'mistral-base-plugin-tacker': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tacker/'
-                     'tacker-stable-victoria.tar.gz')},
+                     'tacker-${openstack_branch}.tar.gz')},
     'monasca-agent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-agent/'
-                     'monasca-agent-stable-victoria.tar.gz')},
+                     'monasca-agent-${openstack_branch}.tar.gz')},
     'monasca-api': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-api/'
-                     'monasca-api-stable-victoria.tar.gz')},
+                     'monasca-api-${openstack_branch}.tar.gz')},
     'monasca-notification': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-notification/'
-                     'monasca-notification-stable-victoria.tar.gz')},
+                     'monasca-notification-${openstack_branch}.tar.gz')},
     'monasca-persister': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-persister/'
-                     'monasca-persister-stable-victoria.tar.gz')},
+                     'monasca-persister-${openstack_branch}.tar.gz')},
     'monasca-statsd': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-statsd/'
-                     'monasca-statsd-stable-victoria.tar.gz')},
+                     'monasca-statsd-${openstack_branch}.tar.gz')},
     # FIXME(dszumski): Use openstack tar when infra is fixed
     'monasca-thresh': {
         'type': 'url',
         'location': ('https://github.com/openstack/monasca-thresh/archive/'
-                     'stable/victoria.tar.gz')},
+                     'master.tar.gz')},
     'monasca-thresh-additions-monasca-common': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-common/'
-                     'monasca-common-stable-victoria.tar.gz')},
+                     'monasca-common-${openstack_branch}.tar.gz')},
     'murano-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/murano/'
-                     'murano-stable-victoria.tar.gz')},
+                     'murano-${openstack_branch}.tar.gz')},
     'neutron-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron/'
-                     'neutron-stable-victoria.tar.gz')},
-    'neutron-base-plugin-networking-ansible': {
-        'type': 'url',
-        'location': ('$tarballs_base/x/networking-ansible/'
-                     'networking-ansible-master.tar.gz')},
+                     'neutron-${openstack_branch}.tar.gz')},
     'neutron-base-plugin-networking-baremetal': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-baremetal/'
-                     'networking-baremetal-stable-victoria.tar.gz')},
+                     'networking-baremetal-${openstack_branch}.tar.gz')},
     'neutron-base-plugin-networking-generic-switch': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-generic-switch/'
-                     'networking-generic-switch-stable-victoria.tar.gz')},
-    'neutron-base-plugin-networking-mlnx': {
-        'type': 'url',
-        'location': ('$tarballs_base/x/networking-mlnx/'
-                     'networking-mlnx-stable-victoria.tar.gz')},
+                     'networking-generic-switch-${openstack_branch}.tar.gz')},
     'neutron-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-sfc/'
-                     'networking-sfc-stable-victoria.tar.gz')},
-    'neutron-base-plugin-vmware-nsx': {
-        'type': 'url',
-        'location': ('$tarballs_base/x/vmware-nsx/'
-                     'vmware-nsx-master.tar.gz')},
+                     'networking-sfc-${openstack_branch}.tar.gz')},
     'neutron-base-plugin-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-vpnaas/'
-                     'neutron-vpnaas-stable-victoria.tar.gz')},
+                     'neutron-vpnaas-${openstack_branch}.tar.gz')},
     'neutron-bgp-dragent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-stable-victoria.tar.gz')},
+                     'neutron-dynamic-routing-${openstack_branch}.tar.gz')},
     'neutron-server-plugin-neutron-dynamic-routing': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-stable-victoria.tar.gz')},
-    'neutron-server-plugin-vmware-nsxlib': {
-        'type': 'url',
-        'location': ('$tarballs_base/x/vmware-nsxlib/'
-                     'vmware-nsxlib-master.tar.gz')},
+                     'neutron-dynamic-routing-${openstack_branch}.tar.gz')},
     'neutron-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-vpnaas/'
-                     'neutron-vpnaas-stable-victoria.tar.gz')},
+                     'neutron-vpnaas-${openstack_branch}.tar.gz')},
     'nova-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/nova/'
-                     'nova-stable-victoria.tar.gz')},
+                     'nova-${openstack_branch}.tar.gz')},
     'nova-base-plugin-blazar': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar-nova/'
-                     'blazar-nova-stable-victoria.tar.gz')},
-    'nova-base-plugin-mksproxy': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/nova-mksproxy/'
-                     'nova-mksproxy-0.0.2.tar.gz')},
-    'novajoin-base': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/novajoin/'
-                     'novajoin-1.3.0.tar.gz')},
+                     'blazar-nova-${openstack_branch}.tar.gz')},
     'octavia-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/octavia/'
-                     'octavia-stable-victoria.tar.gz')},
+                     'octavia-${openstack_branch}.tar.gz')},
     'octavia-api-plugin-ovn-octavia-provider': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ovn-octavia-provider/'
-                     'ovn-octavia-provider-stable-victoria.tar.gz')},
+                     'ovn-octavia-provider-${openstack_branch}.tar.gz')},
     'octavia-driver-agent-plugin-ovn-octavia-provider': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ovn-octavia-provider/'
-                     'ovn-octavia-provider-stable-victoria.tar.gz')},
+                     'ovn-octavia-provider-${openstack_branch}.tar.gz')},
     'panko-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/panko/'
-                     'panko-stable-victoria.tar.gz')},
+                     'panko-${openstack_branch}.tar.gz')},
     'placement-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/placement/'
-                     'placement-stable-victoria.tar.gz')},
-    'qinling-base': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/qinling/'
-                     'qinling-stable-victoria.tar.gz')},
+                     'placement-${openstack_branch}.tar.gz')},
     'tempest-plugin-tempest-conf': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/python-tempestconf/'
@@ -639,79 +581,75 @@ SOURCES = {
     'tempest-plugin-barbican': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/barbican-tempest-plugin/'
-                     'barbican_tempest_plugin-1.1.0.tar.gz')},
+                     'barbican_tempest_plugin-1.3.0.tar.gz')},
     'tempest-plugin-blazar': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/blazar-tempest-plugin/'
-                     'blazar_tempest_plugin-0.5.0.tar.gz')},
+                     'blazar_tempest_plugin-0.6.1.tar.gz')},
     'tempest-plugin-cinder': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/cinder-tempest-plugin/'
-                     'cinder-tempest-plugin-1.2.0.tar.gz')},
+                     'cinder-tempest-plugin-1.4.0.tar.gz')},
     'tempest-plugin-ec2api': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ec2api-tempest-plugin/'
-                     'ec2api-tempest-plugin-1.1.0.tar.gz')},
+                     'ec2api-tempest-plugin-1.2.1.tar.gz')},
     'tempest-plugin-heat': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/heat-tempest-plugin/'
-                     'heat-tempest-plugin-1.1.0.tar.gz')},
+                     'heat-tempest-plugin-1.2.0.tar.gz')},
     'tempest-plugin-ironic': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/ironic-tempest-plugin/'
-                     'ironic-tempest-plugin-2.1.0.tar.gz')},
+                     'ironic-tempest-plugin-2.2.0.tar.gz')},
     'tempest-plugin-keystone': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/keystone-tempest-plugin/'
-                     'keystone_tempest_plugin-0.5.0.tar.gz')},
+                     'keystone_tempest_plugin-0.7.0.tar.gz')},
     'tempest-plugin-magnum': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/magnum-tempest-plugin/'
-                     'magnum_tempest_plugin-1.1.0.tar.gz')},
+                     'magnum_tempest_plugin-1.3.0.tar.gz')},
     'tempest-plugin-manila': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/manila-tempest-plugin/'
-                     'manila-tempest-plugin-1.2.0.tar.gz')},
+                     'manila-tempest-plugin-1.4.0.tar.gz')},
     'tempest-plugin-mistral': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/mistral-tempest-plugin/'
-                     'mistral_tempest_tests-1.1.0.tar.gz')},
+                     'mistral_tempest_tests-1.2.0.tar.gz')},
     'tempest-plugin-monasca': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/monasca-tempest-plugin/'
-                     'monasca-tempest-plugin-2.1.0.tar.gz')},
+                     'monasca-tempest-plugin-2.2.1.tar.gz')},
     'tempest-plugin-murano': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/murano-tempest-plugin/'
-                     'murano-tempest-plugin-2.1.0.tar.gz')},
+                     'murano-tempest-plugin-2.2.0.tar.gz')},
     'tempest-plugin-neutron': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/neutron-tempest-plugin/'
-                     'neutron-tempest-plugin-1.2.0.tar.gz')},
+                     'neutron-tempest-plugin-1.4.0.tar.gz')},
     'tempest-plugin-patrole': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/patrole/'
-                     'patrole-0.10.0.tar.gz')},
+                     'patrole-0.12.0.tar.gz')},
     'tempest-plugin-telemetry': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/telemetry-tempest-plugin/'
-                     'telemetry_tempest_plugin-1.1.0.tar.gz')},
+                     'telemetry_tempest_plugin-1.3.0.tar.gz')},
     'tempest-plugin-trove': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/trove-tempest-plugin/'
-                     'trove_tempest_plugin-1.1.0.tar.gz')},
+                     'trove_tempest_plugin-1.2.0.tar.gz')},
     'tempest-plugin-vitrage': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vitrage-tempest-plugin/'
-                     'vitrage-tempest-plugin-5.1.0.tar.gz')},
+                     'vitrage-tempest-plugin-5.3.0.tar.gz')},
     'tempest-plugin-watcher': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/watcher-tempest-plugin/'
-                     'watcher-tempest-plugin-2.1.0.tar.gz')},
-    'tempest-plugin-zaqar': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/zaqar-tempest-plugin/'
-                     'zaqar_tempest_plugin-1.1.0.tar.gz')},
+                     'watcher-tempest-plugin-2.2.0.tar.gz')},
     'rally': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/rally/'
@@ -723,67 +661,63 @@ SOURCES = {
     'sahara-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara/'
-                     'sahara-stable-victoria.tar.gz')},
+                     'sahara-${openstack_branch}.tar.gz')},
     'sahara-base-plugin-ambari': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-ambari/'
-                     'sahara-plugin-ambari-stable-victoria.tar.gz')},
+                     'sahara-plugin-ambari-${openstack_branch}.tar.gz')},
     'sahara-base-plugin-cdh': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-cdh/'
-                     'sahara-plugin-cdh-stable-victoria.tar.gz')},
+                     'sahara-plugin-cdh-${openstack_branch}.tar.gz')},
     'sahara-base-plugin-mapr': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-mapr/'
-                     'sahara-plugin-mapr-stable-victoria.tar.gz')},
+                     'sahara-plugin-mapr-${openstack_branch}.tar.gz')},
     'sahara-base-plugin-spark': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-spark/'
-                     'sahara-plugin-spark-stable-victoria.tar.gz')},
+                     'sahara-plugin-spark-${openstack_branch}.tar.gz')},
     'sahara-base-plugin-storm': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-storm/'
-                     'sahara-plugin-storm-stable-victoria.tar.gz')},
+                     'sahara-plugin-storm-${openstack_branch}.tar.gz')},
     'sahara-base-plugin-vanilla': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/sahara-plugin-vanilla/'
-                     'sahara-plugin-vanilla-stable-victoria.tar.gz')},
-    'searchlight-base': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/searchlight/'
-                     'searchlight-stable-victoria.tar.gz')},
+                     'sahara-plugin-vanilla-${openstack_branch}.tar.gz')},
     'senlin-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/senlin/'
-                     'senlin-stable-victoria.tar.gz')},
+                     'senlin-${openstack_branch}.tar.gz')},
     'solum-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/solum/'
-                     'solum-stable-victoria.tar.gz')},
+                     'solum-${openstack_branch}.tar.gz')},
     'swift-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/swift/'
-                     'swift-stable-victoria.tar.gz')},
+                     'swift-${openstack_branch}.tar.gz')},
     'tacker-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tacker/'
-                     'tacker-stable-victoria.tar.gz')},
+                     'tacker-${openstack_branch}.tar.gz')},
     'tacker-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/networking-sfc/'
-                     'networking-sfc-stable-victoria.tar.gz')},
+                     'networking-sfc-${openstack_branch}.tar.gz')},
     'tempest': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/tempest/'
-                     'tempest-25.0.0.tar.gz')},
+                     'tempest-27.0.0.tar.gz')},
     'trove-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/trove/'
-                     'trove-stable-victoria.tar.gz')},
+                     'trove-${openstack_branch}.tar.gz')},
     'vitrage-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vitrage/'
-                     'vitrage-stable-victoria.tar.gz')},
+                     'vitrage-${openstack_branch}.tar.gz')},
     'vmtp': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vmtp/'
@@ -791,15 +725,11 @@ SOURCES = {
     'watcher-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/watcher/'
-                     'watcher-stable-victoria.tar.gz')},
-    'zaqar-base': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/zaqar/'
-                     'zaqar-stable-victoria.tar.gz')},
+                     'watcher-${openstack_branch}.tar.gz')},
     'zun-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/zun/'
-                     'zun-stable-victoria.tar.gz')}
+                     'zun-${openstack_branch}.tar.gz')}
 }
 
 
@@ -966,10 +896,6 @@ USERS = {
         'uid': 42441,
         'gid': 42441,
     },
-    'searchlight-user': {
-        'uid': 42442,
-        'gid': 42442,
-    },
     'senlin-user': {
         'uid': 42443,
         'gid': 42443,
@@ -1006,10 +932,6 @@ USERS = {
         'uid': 42451,
         'gid': 42451,
     },
-    'zaqar-user': {
-        'uid': 42452,
-        'gid': 42452,
-    },
     'zookeeper-user': {
         'uid': 42453,
         'gid': 42453,
@@ -1022,10 +944,6 @@ USERS = {
         'uid': 42457,
         'gid': 42457,
     },
-    'karbor-user': {
-        'uid': 42458,
-        'gid': 42458,
-    },
     'vitrage-user': {
         'uid': 42459,
         'gid': 42459,
@@ -1070,10 +988,6 @@ USERS = {
         'uid': 42469,
         'gid': 42469,
     },
-    'novajoin-user': {
-        'uid': 42470,
-        'gid': 42470,
-    },
     'blazar-user': {
         'uid': 42471,
         'gid': 42471,
@@ -1126,10 +1040,6 @@ USERS = {
         'uid': 42483,
         'gid': 42483,
     },
-    'qinling-user': {
-        'uid': 42484,
-        'gid': 42484,
-    },
     'masakari-user': {
         'uid': 42485,
         'gid': 42485,
