@@ -80,7 +80,7 @@ LOG = utils.make_a_logger()
 # is irrelevant. Otherwise all must match for skip to happen.
 UNBUILDABLE_IMAGES = {
     'aarch64': {
-        "monasca-grafana",   # no phantomJS on aarch64
+        "bifrost-base",      # someone need to get upstream working first
         "prometheus-mtail",  # no aarch64 binary
         "skydive-base",      # no aarch64 binary
     },
@@ -100,14 +100,9 @@ UNBUILDABLE_IMAGES = {
         "blazar-base",
         "cyborg-base",
         "freezer-base",
-        "karbor-base",
         "kuryr-base",
-        "masakari-base",
         "monasca-base",
         "monasca-thresh",
-        "nova-mksproxy",
-        "qinling-base",
-        "searchlight-base",
         "solum-base",
         "vmtp",
         "zun-base",
@@ -135,8 +130,7 @@ UNBUILDABLE_IMAGES = {
     'debian': {
         "bifrost-base",  # tries to install 'mysql-server' which is not in
                          # Debian 'buster'
-        "monasca-grafana",  # FIXME(hrw): some ssl issues to fix
-        "ovsdpdk",
+        "ovn-base",      # needs more checking
         "qdrouterd",
     },
 
@@ -149,7 +143,6 @@ UNBUILDABLE_IMAGES = {
     },
 
     'centos+aarch64': {
-        "elasticsearch",  # no binary package
         "hacluster-pcs",  # no binary package
         "influxdb",       # no binary package
         "kibana",         # no binary package
@@ -162,32 +155,25 @@ UNBUILDABLE_IMAGES = {
         "kibana",         # no binary package
     },
 
+    "centos+binary": {
+        "masakari-base",
+    },
+
     'debian+binary': {
-        "cloudkitty-base",
-        "ec2-api",
-        "heat-all",
-        "ironic-neutron-agent",
-        "nova-serialproxy",
-        "novajoin-base",
-        "senlin-conductor",  # no binary package
-        "senlin-health-manager",  # no binary package
-        "tacker-base",
-        "trove-base",          # package is not installable
-        "neutron-mlnx-agent",
+        "cloudkitty-base",       # no support in Dockerfile
+        "ironic-neutron-agent",  # no support in Dockerfile
+        "nova-serialproxy",      # no binary package
+        "tacker-base",           # no binary package
     },
 
     'ubuntu+binary': {
         "cloudkitty-base",
-        "ec2-api",
-        "heat-all",
         "ironic-neutron-agent",
-        "novajoin-base",
         "rally",
         "senlin-conductor",  # no binary package
         "senlin-health-manager",  # no binary package
         "tacker-base",
         "vitrage-base",
-        "zaqar",
         "neutron-mlnx-agent",
     },
 }
@@ -705,7 +691,7 @@ class KollaWorker(object):
         if self.base in rh_base:
             self.conf.distro_python_version = "3.6"
         elif self.base in ['debian']:
-            self.conf.distro_python_version = "3.7"
+            self.conf.distro_python_version = "3.9"
         elif self.base in ['ubuntu']:
             self.conf.distro_python_version = "3.8"
         else:
@@ -769,6 +755,7 @@ class KollaWorker(object):
         self.image_statuses_unmatched = dict()
         self.image_statuses_skipped = dict()
         self.image_statuses_unbuildable = dict()
+        self.image_statuses_allowed_to_fail = dict()
         self.maintainer = conf.maintainer
         self.distro_python_version = conf.distro_python_version
 
@@ -926,7 +913,7 @@ class KollaWorker(object):
 
     def create_dockerfiles(self):
         kolla_version = version.version_info.cached_version_string()
-        supported_distro_release = common_config.DISTRO_RELEASE.get(
+        supported_distro_name = common_config.DISTRO_PRETTY_NAME.get(
             self.base)
         for path in self.docker_build_paths:
             template_name = "Dockerfile.j2"
@@ -942,7 +929,7 @@ class KollaWorker(object):
                       'base_package_type': self.base_package_type,
                       'debian_arch': self.debian_arch,
                       'docker_healthchecks': self.docker_healthchecks,
-                      'supported_distro_release': supported_distro_release,
+                      'supported_distro_name': supported_distro_name,
                       'install_metatype': self.install_metatype,
                       'image_prefix': self.image_prefix,
                       'infra_image_prefix': self.infra_image_prefix,
@@ -1164,12 +1151,19 @@ class KollaWorker(object):
                     'name': name,
                 })
 
-        if self.image_statuses_bad:
+        if self.image_statuses_bad or self.image_statuses_allowed_to_fail:
             LOG.info("===========================")
             LOG.info("Images that failed to build")
             LOG.info("===========================")
-            for name, status in sorted(self.image_statuses_bad.items()):
-                LOG.error('%s Failed with status: %s', name, status.value)
+            all_bad_statuses = self.image_statuses_bad.copy()
+            all_bad_statuses.update(self.image_statuses_allowed_to_fail)
+            for name, status in sorted(all_bad_statuses.items()):
+                if name in self.image_statuses_allowed_to_fail:
+                    LOG.error('%s Failed with status: %s (allowed to fail)',
+                              name, status.value)
+                else:
+                    LOG.error('%s Failed with status: %s', name, status.value)
+
                 results['failed'].append({
                     'name': name,
                     'status': status.value,
@@ -1222,12 +1216,14 @@ class KollaWorker(object):
                 self.image_statuses_good,
                 self.image_statuses_unmatched,
                 self.image_statuses_skipped,
-                self.image_statuses_unbuildable]):
+                self.image_statuses_unbuildable,
+                self.image_statuses_allowed_to_fail]):
             return (self.image_statuses_bad,
                     self.image_statuses_good,
                     self.image_statuses_unmatched,
                     self.image_statuses_skipped,
-                    self.image_statuses_unbuildable)
+                    self.image_statuses_unbuildable,
+                    self.image_statuses_allowed_to_fail)
         for image in self.images:
             if image.status == Status.BUILT:
                 self.image_statuses_good[image.name] = image.status
@@ -1238,12 +1234,17 @@ class KollaWorker(object):
             elif image.status == Status.UNBUILDABLE:
                 self.image_statuses_unbuildable[image.name] = image.status
             else:
-                self.image_statuses_bad[image.name] = image.status
+                if image.name in self.conf.allowed_to_fail:
+                    self.image_statuses_allowed_to_fail[
+                        image.name] = image.status
+                else:
+                    self.image_statuses_bad[image.name] = image.status
         return (self.image_statuses_bad,
                 self.image_statuses_good,
                 self.image_statuses_unmatched,
                 self.image_statuses_skipped,
-                self.image_statuses_unbuildable)
+                self.image_statuses_unbuildable,
+                self.image_statuses_allowed_to_fail)
 
     def build_image_list(self):
         def process_source_installation(image, section):
@@ -1414,8 +1415,9 @@ class KollaWorker(object):
 def run_build():
     """Build container images.
 
-    :return: A 4-tuple containing bad, good, unmatched and skipped container
-    image status dicts, or None if no images were built.
+    :return: A 6-tuple containing bad, good, unmatched, skipped,
+    unbuildable and allowed to fail container image status dicts,
+    or None if no images were built.
     """
     conf = cfg.ConfigOpts()
     common_config.parse(conf, sys.argv[1:], prog='kolla-build')
